@@ -159,9 +159,9 @@ def DownloadData(Dir, Var, Startdate, Enddate, latlim, lonlim, TimeStep, Period,
                 else:
                     number2 = 0
                                
-                if Var == "swgnet":
+                if Var == "swgnet" or Var == "swgdn":
                     url_MERRA = r"https://goldsmr4.gesdisc.eosdis.nasa.gov/data/MERRA2/M2T1NXRAD.5.12.4/%d/%02d/MERRA2_%s0%s.tavg1_2d_rad_Nx.%d%02d%02d.nc4" %(year, month, number, number2, year, month, day)
-                if Var == "prectotcorr":
+                elif Var == "prectotcorr":
                     url_MERRA = r"https://goldsmr4.gesdisc.eosdis.nasa.gov/data/MERRA2/M2T1NXFLX.5.12.4/%d/%02d/MERRA2_%s0%s.tavg1_2d_flx_Nx.%d%02d%02d.nc4" %(year, month, number, number2, year, month, day)   
                 else:    
                     url_MERRA = r"https://goldsmr4.gesdisc.eosdis.nasa.gov/data/MERRA2/M2I1NXASM.5.12.4/%d/%02d/MERRA2_%s0%s.inst1_2d_asm_Nx.%d%02d%02d.nc4" %(year, month, number, number2, year, month, day)
@@ -346,6 +346,7 @@ def Get_NC_data_end(file_name,Var, TimeStep, Period, IDy, IDx, VarInfo):
          'ps': 'PS',
          'slp': 'SLP',
          'swgnet': 'SWGDN',
+         'swgdn': 'SWGDN',        
          'prectotcorr': 'PRECTOTCORR'}  
       
     types  = VarInfo.types[Var]
@@ -378,7 +379,8 @@ class VariablesInfo:
              'tpw': 'Total_Precipitable_Water_Vapor',
              'ps': 'Surface_Pressure',
              'slp': 'Sea_Level_Pressure',
-             'swgnet': 'Surface_Net_Downward_Shortwave_Flux',
+             'swgnet': 'Surface_Net_Downward_Shortwave_Flux',             
+             'swgdn': 'Surface_Incoming_Shortwave_Flux',
              'prectotcorr': 'Total_Precipitation_Corrected'
              }
     
@@ -390,6 +392,7 @@ class VariablesInfo:
              'ps': 'Surface Pressure',
              'slp': 'Sea Level Pressure',
              'swgnet': 'Surface Net Downward Shortwave Flux',
+             'swgdn': 'Surface Incoming Shortwave Flux',             
              'prectotcorr': 'Total Precipitation Corrected'             
              }
     
@@ -401,7 +404,8 @@ class VariablesInfo:
              'ps': 0.001,
              'slp':  0.001,
              'swgnet':  1,
-             'prectotcorr':  86400 }
+             'swgdn':  1,
+             'prectotcorr':  3600}
     
     types = {'t2m': 'state',
              'u2m': 'state',
@@ -411,6 +415,7 @@ class VariablesInfo:
              'ps': 'state',
              'slp': 'state',
              'swgnet': 'state',
+             'swgdn': 'state',
              'prectotcorr': 'flux'
              }
 
@@ -424,6 +429,7 @@ class VariablesInfo:
              'ps': 'kpa',
              'slp': 'kpa',
              'swgnet': 'W-m-2',
+             'swgdn': 'W-m-2',             
              'prectotcorr': 'mm'
              }
             
@@ -436,6 +442,7 @@ class VariablesInfo:
              'ps': 'kpa',
              'slp': 'kpa',
              'swgnet': 'W-m-2',
+             'swgdn': 'W-m-2',
              'prectotcorr': 'mm'
              }    
             
@@ -448,6 +455,7 @@ class VariablesInfo:
              'ps': 'kpa',
              'slp': 'kpa',
              'swgnet': 'W-m-2',
+             'swgdn': 'W-m-2',             
              'prectotcorr': 'mm'
              }
             
@@ -460,6 +468,7 @@ class VariablesInfo:
              'ps': 'kpa',
              'slp': 'kpa',
              'swgnet': 'W-m-2',
+             'swgdn': 'W-m-2',             
              'prectotcorr': 'mm'
              }
         else:
