@@ -643,10 +643,12 @@ def reproject_MODIS(input_name, epsg_to):
 
     return(name_out)
 
-def reproject_shapefile(input_shp, epsg_to):
+def reproject_shapefile(input_shp, epsg_to, output_shp_name=False):
 
     input_shp_name_base, input_shp_name_ext= os.path.splitext(input_shp)
-    output_shp_name = ''.join([input_shp_name_base, "_EPSG%s" %epsg_to, input_shp_name_ext])
+    
+    if output_shp_name==False:
+        output_shp_name = ''.join([input_shp_name_base, "_EPSG%s" %epsg_to, input_shp_name_ext])
     
     shpf = shapefile.Reader(input_shp)
     wgs_shp = shapefile.Writer(output_shp_name, shapeType=5)
@@ -904,9 +906,9 @@ def Get_epsg(g, extension = 'tiff'):
     try:
         if extension == 'tiff':
             # Get info of the dataset that is used for transforming
-            try:
+            if str(type(g)) != "<class 'osgeo.gdal.Dataset'>":
                 dest = gdal.Open(g)
-            except:
+            else:
                 dest = g
             g_proj = dest.GetProjection()
             Projection=g_proj.split('EPSG","')
@@ -1148,6 +1150,50 @@ def Vector_to_Raster(shapefile_name, filename, Attribute_name):
     
     return(Raster_Basin)
 
+def Raster_to_Vector(filename, shapefile_name):
+    """
+    This function creates a vector of a raster file
+
+    Keyword arguments:
+    shapefile_name -- 'C:/....../.shp'
+        str: Path from the shape file
+    reference_raster_data_name -- destination file as example file
+
+    """
+    try:
+        if filename.split('.')[-1] == 'tif':
+            src_ds = gdal.Open(r"%s" %filename)
+        else:
+            src_ds = filename
+    except:
+            src_ds = filename      
+
+    proj = Get_epsg(src_ds)
+    # geo = src_ds.GetGeoTransform()
+    # size_X = src_ds.RasterXSize
+    # size_Y = src_ds.RasterYSize
+ 
+    srs = osr.SpatialReference()
+    srs.ImportFromWkt(src_ds.GetProjection())
+    srcband = src_ds.GetRasterBand(1)
+    dst_layername = "PolyFtr"
+    drv = ogr.GetDriverByName("ESRI Shapefile")
+    dst_ds = drv.CreateDataSource(shapefile_name)
+    dst_layer = dst_ds.CreateLayer(dst_layername, srs = None)
+    newField = ogr.FieldDefn('DN', ogr.OFTInteger)
+    dst_layer.CreateField(newField)
+    gdal.Polygonize(srcband, None, dst_layer, 0, [], 
+    callback=None )    
+    dst_ds.Destroy() 
+    
+    proj_filename =  os.path.join(os.path.dirname(shapefile_name), os.path.basename(shapefile_name).replace(".shp",".prj"))
+    prj = open(proj_filename, "w")
+    epsg = getWKT_PRJ("%s" %proj)
+    prj.write(epsg)
+    prj.close()   
+    
+    return()
+
 def Moving_average(dataset, Moving_front, Moving_back):
     """
     This function applies the moving averages over a 3D matrix called dataset.
@@ -1197,24 +1243,23 @@ def Create_Buffer(Data_In, Buffer_area = 2):
    Data_Out=np.empty((len(Data_In),len(Data_In[1])))
    Data_Out[:,:] = Data_In
    for ypixel in range(0,Buffer_area + 1):
+        if ypixel==0:
+             for xpixel in range(1,Buffer_area + 1):
+                 Data_Out[:,0:-xpixel] += Data_In[:,xpixel:]
+                 Data_Out[:,xpixel:] += Data_In[:,:-xpixel]
 
-        for xpixel in range(1,Buffer_area + 1):
+             for ypixel in range(1,Buffer_area + 1):
 
-           if ypixel==0:
-                for xpixel in range(1,Buffer_area + 1):
-                    Data_Out[:,0:-xpixel] += Data_In[:,xpixel:]
-                    Data_Out[:,xpixel:] += Data_In[:,:-xpixel]
+                 Data_Out[ypixel:,:] += Data_In[:-ypixel,:]
+                 Data_Out[0:-ypixel,:] += Data_In[ypixel:,:]
 
-                for ypixel in range(1,Buffer_area + 1):
+        else:
+            for xpixel in range(1,Buffer_area + 1):
 
-                    Data_Out[ypixel:,:] += Data_In[:-ypixel,:]
-                    Data_Out[0:-ypixel,:] += Data_In[ypixel:,:]
-
-           else:
-               Data_Out[0:-xpixel,ypixel:] += Data_In[xpixel:,:-ypixel]
-               Data_Out[xpixel:,ypixel:] += Data_In[:-xpixel,:-ypixel]
-               Data_Out[0:-xpixel,0:-ypixel] += Data_In[xpixel:,ypixel:]
-               Data_Out[xpixel:,0:-ypixel] += Data_In[:-xpixel,ypixel:]
+                Data_Out[0:-xpixel,ypixel:] += Data_In[xpixel:,:-ypixel]
+                Data_Out[xpixel:,ypixel:] += Data_In[:-xpixel,:-ypixel]
+                Data_Out[0:-xpixel,0:-ypixel] += Data_In[xpixel:,ypixel:]
+                Data_Out[xpixel:,0:-ypixel] += Data_In[:-xpixel,ypixel:]
 
    Data_Out[Data_Out>0.1] = 1
    Data_Out[Data_Out<=0.1] = 0
